@@ -1,7 +1,7 @@
 /* expat_config.h.cmake.  Based upon generated expat_config.h.in.  */
 
 #ifndef EXPAT_CONFIG_H
-#define EXPAT_CONFIG_H 1
+#  define EXPAT_CONFIG_H 1
 
 /* 1234 = LIL_ENDIAN, 4321 = BIGENDIAN */
 #define BYTEORDER 1234
@@ -10,7 +10,7 @@
 /* #undef HAVE_ARC4RANDOM */
 
 /* Define to 1 if you have the `arc4random_buf' function. */
-#define HAVE_ARC4RANDOM_BUF
+/* #undef HAVE_ARC4RANDOM_BUF */
 
 /* Define to 1 if you have the <dlfcn.h> header file. */
 #define HAVE_DLFCN_H
@@ -19,7 +19,7 @@
 #define HAVE_FCNTL_H
 
 /* Define to 1 if you have the `getpagesize' function. */
-#define HAVE_GETPAGESIZE
+/* #undef HAVE_GETPAGESIZE */
 
 /* Define to 1 if you have the `getrandom' function. */
 #define HAVE_GETRANDOM
@@ -61,7 +61,7 @@
 #define HAVE_UNISTD_H
 
 /* Name of package */
-#define PACKAGE "expat"
+#  define PACKAGE "expat"
 
 /* Define to the address where bug reports for this package should be sent. */
 #define PACKAGE_BUGREPORT "https://github.com/libexpat/libexpat/issues"
@@ -70,21 +70,21 @@
 #define PACKAGE_NAME "expat"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "expat 2.6.2"
+#define PACKAGE_STRING "expat 2.7.2"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "expat"
 
 /* Define to the home page for this package. */
-#define PACKAGE_URL ""
+#  define PACKAGE_URL ""
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "2.6.2"
+#define PACKAGE_VERSION "2.7.2"
 
 /* Define to 1 if you have the ANSI C header files. */
-#ifndef STDC_HEADERS
+#  ifndef STDC_HEADERS
 #define STDC_HEADERS
-#endif
+#  endif
 
 /* whether byteorder is bigendian */
 /* #undef WORDS_BIGENDIAN */
@@ -95,31 +95,28 @@
 
 /* Define to specify how much context to retain around the current parse
    point, 0 to disable. */
-#define XML_CONTEXT_BYTES 1024
+#  define XML_CONTEXT_BYTES 1024
 
-#if ! defined(_WIN32)
+#  if ! defined(_WIN32)
 /* Define to include code reading entropy from `/dev/urandom'. */
 #define XML_DEV_URANDOM
-#endif
+#  endif
 
 /* Define to make parameter entity parsing functionality available. */
 #define XML_DTD
 
 /* Define as 1/0 to enable/disable support for general entities. */
-#define XML_GE 1
+#  define XML_GE 1
 
 /* Define to make XML Namespaces functionality available. */
 #define XML_NS
 
 /* Define to __FUNCTION__ or "" if `__func__' does not conform to ANSI C. */
-#ifdef _MSC_VER
-#  define __func__ __FUNCTION__
-#endif
+#  ifdef _MSC_VER
+#    define __func__ __FUNCTION__
+#  endif
 
 /* Define to `long' if <sys/types.h> does not define. */
 /* #undef off_t */
 
-/* Define to `unsigned' if <sys/types.h> does not define. */
-/* #undef size_t */
-
 #endif // ndef EXPAT_CONFIG_H
